#ifndef OPTIONS_H
#define OPTIONS_H

#include <QWidget>
#include <QSplashScreen>

namespace Ui {
    class Options;
}

class Options : public QSplashScreen
{
    Q_OBJECT

public:
    explicit Options(QWidget *parent = 0);
    ~Options();

private slots:
    void on_closeButton_clicked();

    void on_cancelPushButton_clicked();

    void on_clearButton_clicked();

    void on_removePlaylists_clicked();

signals:
    void closeButtonClicked();
    void clearCurrentClicked();
    void removePlaylistsButtonClicked();

private:
    Ui::Options *ui;
};

#endif // OPTIONS_H
